pub enum ConfigKeyError {
Empty,
EmptySegment,
DottedSegment,
}Expand description
Error returned when a configuration key, section, or path is invalid.
Variants
Empty
The provided key or path was empty after trimming whitespace.
EmptySegment
A dotted path contained an empty segment.
DottedSegment
A single key or section segment contained a dot.