ConfigValue

Enum ConfigValue 

pub enum ConfigValue {
    Null,
    Bool(bool),
    Integer(i64),
    Float(f64),
    String(String),
    List(Vec<ConfigValue>),
    Map(BTreeMap<String, ConfigValue>),
}
A primitive deterministic configuration value.

Variants



Null

No configured value.



Bool(bool)

Boolean value.



Integer(i64)

Signed integer value.



Float(f64)

Floating-point value.



String(String)

Owned string value.



List(Vec<ConfigValue>)

Ordered list of configuration values.



Map(BTreeMap<String, ConfigValue>)

Deterministically ordered string-keyed map.

Implementations

Source

impl ConfigValue

pub const fn as_bool(&self) -> Option<bool>

Returns the boolean value, if this is a boolean.

pub const fn as_i64(&self) -> Option<i64>

Returns the integer value, if this is an integer.

pub const fn as_f64(&self) -> Option<f64>

Returns the floating-point value, if this is a float.

pub fn as_str(&self) -> Option<&str>

Returns the string value, if this is a string.

pub fn as_list(&self) -> Option<&[ConfigValue]>

Returns the list value, if this is a list.

pub const fn as_map(&self) -> Option<&BTreeMap<String, ConfigValue>>

Returns the map value, if this is a map.