pub struct ConfigPath { /* private fields */ }Expand description
A validated dotted configuration path.
Implementations
Sourceimpl ConfigPath
impl ConfigPath
Sourcepub fn parse(input: &str) -> Result<ConfigPath, ConfigKeyError>
pub fn parse(input: &str) -> Result<ConfigPath, ConfigKeyError>
Parses a dotted configuration path.
Errors
Returns ConfigKeyError when the path is empty or contains an invalid segment.
Sourcepub fn from_segments<I, S>(segments: I) -> Result<ConfigPath, ConfigKeyError>
pub fn from_segments<I, S>(segments: I) -> Result<ConfigPath, ConfigKeyError>
Creates a path from already separated segments.
Errors
Returns ConfigKeyError when no segments are provided or any segment is invalid.